==> dif-database-repository-2.3.11-7-sources.jar: pt/digitalis/dif/utils/logging/AuditingLoggerDBImplementation.java <==
/**
 * 2015, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.utils.logging;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import pt.digitalis.dif.dem.managers.impl.audit.model.DIFDBAuditFactory;
import pt.digitalis.dif.dem.managers.impl.audit.model.IAuditService;
import pt.digitalis.dif.dem.managers.impl.audit.model.data.AuditLog;
import pt.digitalis.dif.dem.managers.impl.audit.model.data.AuditLogDetail;
import pt.digitalis.dif.dem.managers.impl.model.data.Acl;
import pt.digitalis.dif.dem.managers.impl.model.data.CustomMessages;
import pt.digitalis.dif.dem.managers.impl.model.data.EcommercePayments;
import pt.digitalis.dif.dem.managers.impl.model.data.ErrorLog;
import pt.digitalis.dif.dem.managers.impl.model.data.Groups;
import pt.digitalis.dif.dem.managers.impl.model.data.PersistentAction;
import pt.digitalis.dif.dem.managers.impl.model.data.PersistentForm;
import pt.digitalis.dif.dem.managers.impl.model.data.UserAttributes;
import pt.digitalis.dif.dem.managers.impl.model.data.UserGroups;
import pt.digitalis.dif.dem.managers.impl.model.data.Users;
import pt.digitalis.dif.ioc.DIFIoCRegistry;
import pt.digitalis.dif.model.dataset.DataSetException;
import pt.digitalis.dif.model.hibernate.AuditDetail;
import pt.digitalis.dif.model.hibernate.IAuditingLogger;
import pt.digitalis.utils.common.StringUtils;

/**
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a><br/>
 * @created 24/11/2015
 */
public class AuditingLoggerDBImplementation implements IAuditingLogger {

    /** control variable to check if the logger instance as already been initialized */
    private boolean isInitialized = false;

    /**  */
    private List<String> tablesNotToLOG = new ArrayList<String>();

    /**
     * Initialization
     * 
     * @param additionalTableNotToLog
     *            a list of table names not to log
     */
    public void initialize(List<String> additionalTableNotToLog)
    {
        if (!isInitialized())
        {
            // Auditing tables are always excluded from auditing
            tablesNotToLOG.add(AuditLog.class.getSimpleName());
            tablesNotToLOG.add(AuditLogDetail.class.getSimpleName());
            tablesNotToLOG.add(PersistentAction.class.getSimpleName());
            tablesNotToLOG.add(PersistentForm.class.getSimpleName());
            tablesNotToLOG.add(ErrorLog.class.getSimpleName());

            // Excluding all table from the DIF schema
            tablesNotToLOG.add(Acl.class.getSimpleName());
            tablesNotToLOG.add(CustomMessages.class.getSimpleName());
            tablesNotToLOG.add(Groups.class.getSimpleName());
            tablesNotToLOG.add(EcommercePayments.class.getSimpleName());
            tablesNotToLOG.add(UserAttributes.class.getSimpleName());
            tablesNotToLOG.add(UserGroups.class.getSimpleName());
            tablesNotToLOG.add(Users.class.getSimpleName());

            if (additionalTableNotToLog != null)
                tablesNotToLOG.addAll(additionalTableNotToLog);

            this.isInitialized = true;
        }
    }

    /**
     * @see pt.digitalis.dif.model.hibernate.IAuditingLogger#isAuditableEntity(java.lang.String)
     */
    public boolean isAuditableEntity(String entityName)
    {
        if (!isInitialized())
            this.initialize(null);

        return !tablesNotToLOG.contains(entityName);
    }

    /**
     * check if the logger instance as already been initialized
     * 
     * @return T if it is initialized
     */
    public final boolean isInitialized()
    {
        return this.isInitialized;
    }

    /**
     * @see pt.digitalis.dif.model.hibernate.IAuditingLogger#logDelete(java.lang.String, java.lang.String,
     *      java.util.List, java.lang.String, java.lang.String, java.lang.String)
     */
    public void logDelete(String entityName, String entityID, List<AuditDetail> details, String userName,
            String appName, String processName) throws Exception
    {
        logEntry('D', entityName, entityID, details, userName, appName, processName);
    }

    /**
     * Logs an DB action to the audit tables
     * 
     * @param operation
     * @param entityName
     * @param entityID
     * @param details
     * @param userName
     * @param appName
     * @param processName
     * @throws DataSetException
     */
    protected void logEntry(Character operation, String entityName, String entityID, List<AuditDetail> details,
            String userName, String appName, String processName) throws DataSetException
    {
        if (isAuditableEntity(entityName))
        {
            userName = StringUtils.nvl(userName, "No user logged");
            appName = StringUtils.nvl(appName, "Undetermined");

            // Trace info
            DIFLogger.getLogger().trace(
                    "Delete record of " + entityName + " issued by: " + userName + " (using \"" + appName + "\")");

            boolean wasActive = DIFDBAuditFactory.openTransaction();

            IAuditService auditDB = DIFIoCRegistry.getRegistry().getImplementation(IAuditService.class);

            // Log to database
            AuditLog log = new AuditLog();
            log.setApp(appName);
            log.setProcess(processName);
            log.setEntityName(entityName);
            log.setInstanceId(entityID);
            log.setOperation(operation);
            log.setOperationDate(new Timestamp(new Date().getTime()));
            log.setUserid(userName);
            log = auditDB.getAuditLogDataSet().insert(log);

            for (AuditDetail detail: details)
            {
                AuditLogDetail logdetail = new AuditLogDetail();
                logdetail.setAuditLog(log);
                logdetail.setColumnName(detail.getFieldName());
                logdetail.setPreviousValue(truncTo4000(detail.getPreviousValue()));
                logdetail.setNewValue(truncTo4000(detail.getNewValue()));
                auditDB.getAuditLogDetailDataSet().insert(logdetail);
            }

            if (!wasActive)
                DIFDBAuditFactory.getSession().getTransaction().commit();
        }
    }

    /**
     * @see pt.digitalis.dif.model.hibernate.IAuditingLogger#logInsert(java.lang.String, java.lang.String,
     *      java.util.List, java.lang.String, java.lang.String, java.lang.String)
     */
    public void logInsert(String entityName, String entityID, List<AuditDetail> details, String userName,
            String appName, String processName) throws Exception
    {
        logEntry('C', entityName, entityID, details, userName, appName, processName);
    }

    /**
     * @see pt.digitalis.dif.model.hibernate.IAuditingLogger#logUpdate(java.lang.String, java.lang.String,
     *      java.util.List, java.lang.String, java.lang.String, java.lang.String)
     */
    public void logUpdate(String entityName, String entityID, List<AuditDetail> details, String userName,
            String appName, String processName) throws Exception
    {
        logEntry('U', entityName, entityID, details, userName, appName, processName);
    }

    /**
     * Limits a value to 4000 characters long
     * 
     * @param value
     * @return the trunacated value
     */
    private String truncTo4000(String value)
    {
        if (value == null)
            return null;
        else
            return value.substring(0, Math.min(value.length(), 3999));
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/utils/logging/AuditingLoggerDBImplementation.java <==
/**
 * 2015, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.utils.logging;

import pt.digitalis.dif.dem.managers.impl.audit.model.DIFDBAuditFactory;
import pt.digitalis.dif.dem.managers.impl.audit.model.IAuditService;
import pt.digitalis.dif.dem.managers.impl.audit.model.data.AuditLog;
import pt.digitalis.dif.dem.managers.impl.audit.model.data.AuditLogDetail;
import pt.digitalis.dif.dem.managers.impl.model.data.Acl;
import pt.digitalis.dif.dem.managers.impl.model.data.CustomMessages;
import pt.digitalis.dif.dem.managers.impl.model.data.EcommercePayments;
import pt.digitalis.dif.dem.managers.impl.model.data.ErrorLog;
import pt.digitalis.dif.dem.managers.impl.model.data.Groups;
import pt.digitalis.dif.dem.managers.impl.model.data.PersistentAction;
import pt.digitalis.dif.dem.managers.impl.model.data.PersistentForm;
import pt.digitalis.dif.dem.managers.impl.model.data.Server;
import pt.digitalis.dif.dem.managers.impl.model.data.ServerActivityLog;
import pt.digitalis.dif.dem.managers.impl.model.data.ServerMessage;
import pt.digitalis.dif.dem.managers.impl.model.data.UserAttributes;
import pt.digitalis.dif.dem.managers.impl.model.data.UserGroups;
import pt.digitalis.dif.dem.managers.impl.model.data.Users;
import pt.digitalis.dif.ioc.DIFIoCRegistry;
import pt.digitalis.dif.model.dataset.DataSetException;
import pt.digitalis.dif.model.hibernate.AuditDetail;
import pt.digitalis.dif.model.hibernate.IAuditingLogger;
import pt.digitalis.utils.common.StringUtils;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a><br/>
 * @created 24/11/2015
 */
public class AuditingLoggerDBImplementation implements IAuditingLogger
{

    /** control variable to check if the logger instance as already been initialized */
    private boolean isInitialized = false;

    /**
     *
     */
    private List<String> tablesNotToLOG = new ArrayList<String>();

    /**
     * Initialization
     *
     * @param additionalTableNotToLog a list of table names not to log
     */
    public void initialize(List<String> additionalTableNotToLog)
    {
        if (!isInitialized())
        {
            // Auditing tables are always excluded from auditing
            tablesNotToLOG.add(AuditLog.class.getSimpleName());
            tablesNotToLOG.add(AuditLogDetail.class.getSimpleName());
            tablesNotToLOG.add(PersistentAction.class.getSimpleName());
            tablesNotToLOG.add(PersistentForm.class.getSimpleName());
            tablesNotToLOG.add(ErrorLog.class.getSimpleName());

            // Excluding all table from the DIF schema
            tablesNotToLOG.add(Acl.class.getSimpleName());
            tablesNotToLOG.add(CustomMessages.class.getSimpleName());
            tablesNotToLOG.add(Groups.class.getSimpleName());
            tablesNotToLOG.add(EcommercePayments.class.getSimpleName());
            tablesNotToLOG.add(UserAttributes.class.getSimpleName());
            tablesNotToLOG.add(UserGroups.class.getSimpleName());
            tablesNotToLOG.add(Users.class.getSimpleName());

            tablesNotToLOG.add(Server.class.getSimpleName());
            tablesNotToLOG.add(ServerActivityLog.class.getSimpleName());
            tablesNotToLOG.add(ServerMessage.class.getSimpleName());

            if (additionalTableNotToLog != null)
                tablesNotToLOG.addAll(additionalTableNotToLog);

            this.isInitialized = true;
        }
    }

    /**
     * @see pt.digitalis.dif.model.hibernate.IAuditingLogger#isAuditableEntity(java.lang.String)
     */
    public boolean isAuditableEntity(String entityName)
    {
        if (!isInitialized())
            this.initialize(null);

        return !tablesNotToLOG.contains(entityName);
    }

    /**
     * check if the logger instance as already been initialized
     *
     * @return T if it is initialized
     */
    public final boolean isInitialized()
    {
        return this.isInitialized;
    }

    /**
     * @see pt.digitalis.dif.model.hibernate.IAuditingLogger#logDelete(java.lang.String, java.lang.String,
     *         java.util.List, java.lang.String, java.lang.String, java.lang.String)
     */
    public void logDelete(String entityName, String entityID, List<AuditDetail> details, String userName,
            String appName, String processName) throws Exception
    {
        logEntry('D', entityName, entityID, details, userName, appName, processName);
    }

    /**
     * Logs an DB action to the audit tables
     *
     * @param operation
     * @param entityName
     * @param entityID
     * @param details
     * @param userName
     * @param appName
     * @param processName
     *
     * @exception DataSetException
     */
    protected void logEntry(Character operation, String entityName, String entityID, List<AuditDetail> details,
            String userName, String appName, String processName) throws DataSetException
    {
        if (isAuditableEntity(entityName))
        {
            userName = StringUtils.nvl(userName, "No user logged");
            appName = StringUtils.nvl(appName, "Undetermined");

            // Trace info
            DIFLogger.getLogger()
                    .trace("Delete record of " + entityName + " issued by: " + userName + " (using \"" + appName +
                           "\")");

            boolean wasActive = DIFDBAuditFactory.openTransaction();

            IAuditService auditDB = DIFIoCRegistry.getRegistry().getImplementation(IAuditService.class);

            // Log to database
            AuditLog log = new AuditLog();
            log.setApp(appName);
            log.setProcess(processName);
            log.setEntityName(entityName);
            log.setInstanceId(entityID);
            log.setOperation(operation);
            log.setOperationDate(new Timestamp(new Date().getTime()));
            log.setUserid(userName);
            log = auditDB.getAuditLogDataSet().insert(log);

            for (AuditDetail detail : details)
            {
                AuditLogDetail logdetail = new AuditLogDetail();
                logdetail.setAuditLog(log);
                logdetail.setColumnName(detail.getFieldName());
                logdetail.setPreviousValue(truncTo4000(detail.getPreviousValue()));
                logdetail.setNewValue(truncTo4000(detail.getNewValue()));
                auditDB.getAuditLogDetailDataSet().insert(logdetail);
            }

            if (!wasActive)
                DIFDBAuditFactory.getSession().getTransaction().commit();
        }
    }

    /**
     * @see pt.digitalis.dif.model.hibernate.IAuditingLogger#logInsert(java.lang.String, java.lang.String,
     *         java.util.List, java.lang.String, java.lang.String, java.lang.String)
     */
    public void logInsert(String entityName, String entityID, List<AuditDetail> details, String userName,
            String appName, String processName) throws Exception
    {
        logEntry('C', entityName, entityID, details, userName, appName, processName);
    }

    /**
     * @see pt.digitalis.dif.model.hibernate.IAuditingLogger#logUpdate(java.lang.String, java.lang.String,
     *         java.util.List, java.lang.String, java.lang.String, java.lang.String)
     */
    public void logUpdate(String entityName, String entityID, List<AuditDetail> details, String userName,
            String appName, String processName) throws Exception
    {
        logEntry('U', entityName, entityID, details, userName, appName, processName);
    }

    /**
     * Limits a value to 4000 characters long
     *
     * @param value
     *
     * @return the trunacated value
     */
    private String truncTo4000(String value)
    {
        if (value == null)
            return null;
        else
            return value.substring(0, Math.min(value.length(), 3999));
    }
}
